==> vtigercrm-5.3.0p0.tgz: modules/CustomView/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License
Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"
basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|07/09/2011|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Customizar Visualização',
'LBL_STEP_1_TITLE'=>'Dados Visualização',
'LBL_VIEW_NAME'=>'Nome Visualização:',
'LBL_SETDEFAULT'=>'Definir como Padrão',
'LBL_LIST_IN_METRICS'=>'Listar em Métricas',
'LBL_STEP_2_TITLE'=>'Selecionar Coluna',
'LBL_STEP_3_TITLE'=>'Filtros Padrões',
'LBL_STEP_4_TITLE'=>'Filtros Avançados',
'LBL_STEP_5_TITLE'=>'Informação Acesso',
'LBL_SF_COLUMNS'=>'Coluna',
'LBL_SF_STARTDATE'=>'Data Inicial',
'LBL_SF_ENDDATE'=>'Data Final',
'LBL_AF_HDR1'=>'Defina as condições da pesquisa para restringir melhor a lista.',
'LBL_AF_HDR2'=>'Você pode usar filtros &quot;ou&quot; entrar com múltiplos
itens na terceira coluna.',
'LBL_AF_HDR3'=>'Você pode entrar com mais de 10 itens, separados por vírgulas. Por
exemplo: PR, SP, MG, RS para procurar PR ou SP ou MG ou RS.',
'LBL_AF_HDR4'=>'Se "Tipo Atividade" for selecionado, atribua um dos
seguintes valores "Chamada", "Reunião" ou "Tarefa".',

//strings added for vtiger 5, date format...
'LBL_NONE'=>'Nada',
'View_Name'=>'View_Name',
'LBL_AND'=>'E',
'LBL_DATE_FORMAT_CUSTOMVIEW'=>'Y-m-d',
//Strings added for filter
'Custom'=>'Customizar',
'Previous FY'=>'Ano Fiscal Anterior',
'Current FY'=>'Ano Fiscal Atual',
'Next FY'=>'Próxima Ano Fiscal',
'Previous FQ'=>'Trimestre Fiscal Anterior',
'Current FQ'=>'Trimestre Fiscal Atual',
'Next FQ'=>'Próximo Trimestre Fiscal',
'Yesterday'=>'Ontem',
'Today'=>'Hoje',
'Tomorrow'=>'Amanhã',
'Last Week'=>'Últma Semana',
'Current Week'=>'Semana Atual',
'Next Week'=>'Próxima Semana',
'Last Month'=>'Último Mês',
'Current Month'=>'Mês atual',
'Next Month'=>'Próximo Mês',
'Last 7 Days'=>'Últimos 7 Dias',
'Last 30 Days'=>'Últimos 30 Dias',
'Last 60 Days'=>'Últimos 60 Dias',
'Last 90 Days'=>'Últimos 90 Dias',
'Last 120 Days'=>'Últimos 120 Dias',
'Next 30 Days'=>'Próximos 30 Dias',
'Next 60 Days'=>'Próximos 60 Dias',
'Next 90 Days'=>'Próximos 90 Dias',
'Next 120 Days'=>'Próximos 120 Dias',
      
'equals'=>'igual',
'contains'=>'Contem',
'does not contain'=>'não contem',
'less than'=>'menor que',
'greater than'=>'maior que',
'less or equal'=>'menor ou igual',
'greater or equal'=>'maior ou igual',
      
//Strings added to translate field label vtiger_groups
'Address'=>'Endereço',
'Information'=>'Informação',
'Description'=>'Descrição',
'Custom Information'=>'Informação Customizada',
'- Event Information'=>'- Informação Evento',
'- Event Description'=>'- Descrição Evento',
'- Task Information'=>'- Informação Tarefa',
'- Task Description'=>'- Descrição Tarefa',

//Strings added for helpdesk module fields
'Title'=>'Título',
'Assigned To'=>'Responsável',
'Related to'=>'Relacionado à',
'Priority'=>'Prioridade',
'Product Name'=>'Nome Produto',
'Severity'=>'Gravidade',
'Status'=>'Status',
'Category'=>'Categoria',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Attachment'=>'Anexo',

//Strings added for Leads module fields
'First Name'=>'Nome',
'Phone'=>'Fone',
'Last Name'=>'Sobrenome',
'Company'=>'Empresa',
'Lead Source'=>'Fonte Lead',
'Website'=>'Website',
'Industry'=>'Atividade',
'Lead Status'=>'Status Lead',
'Annual Revenue'=>'Receita Anual',
'Rating'=>'Avaliação',
'No Of Employees'=>'No. Empregados',
'Street'=>'Rua',
'Po Box'=>'Cx Postal',
'Postal Code'=>'CEP',
'City'=>'Cidade',
'Country'=>'País',
'State'=>'Estado',
      
//Strings added for Accounts module fields
'Account Name'=>'Nome Conta',
'Ticker Symbol'=>'Cód. Bolsa',
'Other Phone'=>'Fone Alternativo',
'Member Of'=>'Membro de',
'Employees'=>'Empregados',
'Other Email'=>'Email Alternativo',
'Ownership'=>'Proprietário',
'industry'=>'atividade',
'SIC Code'=>'Cod CNAE',
'Email Opt Out'=>'Recusa Email',
'Billing Address'=>'Endereço Faturamento',
'Shipping Address'=>'Endereço Entrega',
'Shipping Po Box'=>'Cx Postal Entrega',
'Billing Po Box'=>'Cx Postal Faturamento',
'Billing City'=>'Cidade Faturamento',
'Shipping City'=>'Cidade Entrega',
'Billing State'=>'Estado Faturamento',
'Shipping State'=>'Estado Faturamento',
'Billing Code'=>'CEP Faturamento',
'Shipping Code'=>'CEP Entrega',
'Shipping Country'=>'País Entrega',
'Billing Country'=>'País Faturamento',
      
      
//Strings added for Contacts module fields
      
'Office Phone'=>'Fone Escritório',
'Home Phone'=>'Fone Residencial',
'Birthdate'=>'Aniversário',
'Reports To'=>'Reporta-se à',
'Assistant Phone'=>'Fone Assistente',
'Do Not Call'=>'Recusa Chamada',
'Mailing Street'=>'Endereço Correspondência',
'Other Street'=>'Endereço Alternativo',
'Mailing Po Box'=>'Cx Postal Correspondência',
'Other Po Box'=>'Cx Postal Alternativo',
'Mailing City'=>'Cidade Correspondência',
'Other City'=>'Cidade Alternativo',
'Mailing State'=>'Estado Correspondência',
'Other State'=>'Estado Alternativo',
'Mailing Zip'=>'CEP Correspondência',
'Other Zip'=>'CEP Alternativo',
'Mailing Country'=>'País Correspondência',
'Other Country'=>'País Alternativo',
      
      
//Strings added for Potential module fields
      
'Potential Name'=>'Nome Oportunidade',
'Amount'=>'Montante',
'Expected Close Date'=>'Data Prevista Fechamento',
'Next Step'=>'Próximo Passo',
'Sales Stage'=>'Estágio Vendas',
'Probability'=>'Probabilidade',
      
      
//Strings added for Quotes module fields
'Subject'=>'Assunto',
'Quote Stage'=>'Estágio Cotação',
'Valid Till'=>'Válido até',
'Team'=>'Equipe',
'Contact Name'=>'Nome Contato',
'Carrier'=>'Entregador',
'Shipping'=>'Entrega',
'Inventory Manager'=>'Almoxarife',
      
//Strings added for Sales Orders module fields
'Customer No'=>'Cód. Cliente',
'Quote Name'=>'Nome Cotação',
'Purchase Order'=>'Pedido Compra',
'Due Date'=>'Data Vencimento',
'Pending'=>'Pendente',
'Sales Commission'=>'Comissão Vendas',
'Excise Duty'=>'IPI',
      
//Strings added for Invoices module fields
'Sales Order'=>'Pedido Vendas',
'Invoice Date'=>'Data Fatura',
      
//Strings added for Product module fields
'Product Active'=>'Produto Ativo',
'Product Category'=>'Categoria Produto',
'Sales Start Date'=>'Data Início Vendas',
'Sales End Date'=>'Data Final Vendas',
'Support Start Date'=>'Data Início Suporte',
'Support Expiry Date'=>'Data Final Suporte',
'Vendor Name'=>'Nome Fornecedor',
'Mfr PartNo'=>'Cód Fabricante',
'Vendor PartNo'=>'Cód Fornecedor',
      
'Serial No'=>'No. Serial',
'Product Sheet'=>'Ficha Produto',
'GL Account'=>'Conta Plano Contas',
      
//Strings added for Price book module fields
'Price Book Name'=>'Nome Lista Preço',
'Active'=>'Ativo',
      
//Strings added for tasks & events module fields
'Start Date & Time'=>'Data & Hora Início',
      
//error message
'Missing required fields'=>'vtiger_fields requeridos ausentes',
//Strings added for campaigns
'Campaign Name'=>'Nome Campanha',
'Campaign Type'=>'Tipo Campanha',
'Product'=>'Produto',
'Campaign Status'=>'Status Campanha',
'Expected Revenue'=>'Receita Esperada',
'Budget Cost'=>'Custo Orçado',
'Actual Cost'=>'Custo Atual',
'Expected Response'=>'Resposta Esperada',
'Num Sent'=>'Número Envio',
'Target Audience'=>'Público Alvo',
'TargetSize'=>'Tamanho Alvo',
'Sponsor'=>'Patrocinador',
'Expected Sales Count'=>'Previsão Vendas',
'Expected Response Count'=>'Previsão Resposta',
'Expected ROI'=>'Previsão ROI',
'Actual Sales Count'=>'Vendas Atual',
'Actual Response Count'=>'Resposta Atual',
'Actual ROI'=>'ROI Atual',
      

      
//Added for customview.tpl
      
'LBL_Select_a_Column'=>'Selecione uma Coluna',
'Missing_required_fields'=>'Campos requeridos ausentes',
'Details'=>'Detalhes',
'New_Custom_View'=>'Nova Visualização Customizada',
'Edit_Custom_View'=>'Editar Visualização Customizada',
'LBL_AF_HDR5'=>'Filtro Simples de Data permite-lhe selecionar dados baseados na
<b>Data Criação da Conta</b> ou <b>Data Modificação da Conta</b>',
'Select_Duration'=>'Selecione Duração',
'Simple_Time_Filter'=>'Filtro Simples de Data',
'Start_Date'=>'Data Inicial',
'End_Date'=>'Data Final',
'LBL_RULE'=>'FUNÇÃO',

// Added/Updated for vtiger CRM 5.0.4
'not equal to'=>'Diferente de',
'starts with'=>'Início com',
'ends with'=>'Final com',
//'Product Code'=>'Product Code',

// Added after 5.0.4 GA

//Added for Role based Custom filters 
'LBL_SET_AS_PUBLIC'=>'Definir como Público',
'LBL_NEW'=>'Novo',
'LBL_EDIT'=>'Editar',
'LBL_STATUS_PUBLIC_APPROVE'=>'Aprovar',
'LBL_STATUS_PUBLIC_DENY'=>'Negar',

'LBL_ADVANCED_FILTER' => 'Regra',
);
?>

==> vtigercrm-5.4.0.tgz: modules/CustomView/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License
Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"
basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the Custom View.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Customizar Visualização',
'LBL_STEP_1_TITLE'=>'Dados Visualização',
'LBL_VIEW_NAME'=>'Nome Visualização:',
'LBL_SETDEFAULT'=>'Definir como Padrão',
'LBL_LIST_IN_METRICS'=>'Listar em Métricas',
'LBL_STEP_2_TITLE'=>'Selecionar Coluna',
'LBL_STEP_3_TITLE'=>'Filtros Padrões',
'LBL_STEP_4_TITLE'=>'Filtros Avançados',
'LBL_STEP_5_TITLE'=>'Informação Acesso',
'LBL_SF_COLUMNS'=>'Coluna',
'LBL_SF_STARTDATE'=>'Data Inicial',
'LBL_SF_ENDDATE'=>'Data Final',
'LBL_AF_HDR1'=>'Defina as condições da pesquisa para restringir melhor a lista.',
'LBL_AF_HDR2'=>'Você pode usar filtros &quot;ou&quot; entrar com múltiplos
itens na terceira coluna.',
'LBL_AF_HDR3'=>'Você pode entrar com mais de 10 itens, separados por vírgulas. Por
exemplo: PR, SP, MG, RS para procurar PR ou SP ou MG ou RS.',
'LBL_AF_HDR4'=>'Se "Tipo Atividade" for selecionado, atribua um dos
seguintes valores "Chamada", "Reunião" ou "Tarefa".',

//strings added for vtiger 5, date format...
'LBL_NONE'=>'Nada',
'View_Name'=>'View_Name',
'LBL_AND'=>'E',
'LBL_DATE_FORMAT_CUSTOMVIEW'=>'Y-m-d',
//Strings added for filter
'Custom'=>'Customizar',
'Previous FY'=>'Ano Fiscal Anterior',
'Current FY'=>'Ano Fiscal Atual',
'Next FY'=>'Próxima Ano Fiscal',
'Previous FQ'=>'Trimestre Fiscal Anterior',
'Current FQ'=>'Trimestre Fiscal Atual',
'Next FQ'=>'Próximo Trimestre Fiscal',
'Yesterday'=>'Ontem',
'Today'=>'Hoje',
'Tomorrow'=>'Amanhã',
'Last Week'=>'Últma Semana',
'Current Week'=>'Semana Atual',
'Next Week'=>'Próxima Semana',
'Last Month'=>'Último Mês',
'Current Month'=>'Mês atual',
'Next Month'=>'Próximo Mês',
'Last 7 Days'=>'Últimos 7 Dias',
'Last 30 Days'=>'Últimos 30 Dias',
'Last 60 Days'=>'Últimos 60 Dias',
'Last 90 Days'=>'Últimos 90 Dias',
'Last 120 Days'=>'Últimos 120 Dias',
'Next 30 Days'=>'Próximos 30 Dias',
'Next 60 Days'=>'Próximos 60 Dias',
'Next 90 Days'=>'Próximos 90 Dias',
'Next 120 Days'=>'Próximos 120 Dias',
      
'equals'=>'igual',
'contains'=>'Contem',
'does not contain'=>'não contem',
'less than'=>'menor que',
'greater than'=>'maior que',
'less or equal'=>'menor ou igual',
'greater or equal'=>'maior ou igual',
      
//Strings added to translate field label vtiger_groups
'Address'=>'Endereço',
'Information'=>'Informação',
'Description'=>'Descrição',
'Custom Information'=>'Informação Customizada',
'- Event Information'=>'- Informação Evento',
'- Event Description'=>'- Descrição Evento',
'- Task Information'=>'- Informação Tarefa',
'- Task Description'=>'- Descrição Tarefa',

//Strings added for helpdesk module fields
'Title'=>'Título',
'Assigned To'=>'Responsável',
'Related to'=>'Relacionado à',
'Priority'=>'Prioridade',
'Product Name'=>'Nome Produto',
'Severity'=>'Gravidade',
'Status'=>'Status',
'Category'=>'Categoria',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
'Attachment'=>'Anexo',

//Strings added for Leads module fields
'First Name'=>'Nome',
'Phone'=>'Fone',
'Last Name'=>'Sobrenome',
'Company'=>'Empresa',
'Lead Source'=>'Fonte Lead',
'Website'=>'Website',
'Industry'=>'Atividade',
'Lead Status'=>'Status Lead',
'Annual Revenue'=>'Receita Anual',
'Rating'=>'Avaliação',
'No Of Employees'=>'No. Empregados',
'Street'=>'Rua',
'Po Box'=>'Cx Postal',
'Postal Code'=>'CEP',
'City'=>'Cidade',
'Country'=>'País',
'State'=>'Estado',
      
//Strings added for Accounts module fields
'Account Name'=>'Nome Organização',
'Ticker Symbol'=>'Cód. Bolsa',
'Other Phone'=>'Fone Alternativo',
'Member Of'=>'Membro de',
'Employees'=>'Empregados',
'Other Email'=>'Email Alternativo',
'Ownership'=>'Proprietário',
'industry'=>'atividade',
'SIC Code'=>'Cod CNAE',
'Email Opt Out'=>'Recusa Email',
'Billing Address'=>'Endereço Faturamento',
'Shipping Address'=>'Endereço Entrega',
'Shipping Po Box'=>'Cx Postal Entrega',
'Billing Po Box'=>'Cx Postal Faturamento',
'Billing City'=>'Cidade Faturamento',
'Shipping City'=>'Cidade Entrega',
'Billing State'=>'Estado Faturamento',
'Shipping State'=>'Estado Faturamento',
'Billing Code'=>'CEP Faturamento',
'Shipping Code'=>'CEP Entrega',
'Shipping Country'=>'País Entrega',
'Billing Country'=>'País Faturamento',
      
      
//Strings added for Contacts module fields
      
'Office Phone'=>'Fone Escritório',
'Home Phone'=>'Fone Residencial',
'Birthdate'=>'Aniversário',
'Reports To'=>'Reporta-se à',
'Assistant Phone'=>'Fone Assistente',
'Do Not Call'=>'Recusa Chamada',
'Mailing Street'=>'Endereço Correspondência',
'Other Street'=>'Endereço Alternativo',
'Mailing Po Box'=>'Cx Postal Correspondência',
'Other Po Box'=>'Cx Postal Alternativo',
'Mailing City'=>'Cidade Correspondência',
'Other City'=>'Cidade Alternativo',
'Mailing State'=>'Estado Correspondência',
'Other State'=>'Estado Alternativo',
'Mailing Zip'=>'CEP Correspondência',
'Other Zip'=>'CEP Alternativo',
'Mailing Country'=>'País Correspondência',
'Other Country'=>'País Alternativo',
      
      
//Strings added for Potential module fields
      
'Potential Name'=>'Nome Oportunidade',
'Amount'=>'Montante',
'Expected Close Date'=>'Data Prevista Fechamento',
'Next Step'=>'Próximo Passo',
'Sales Stage'=>'Estágio Vendas',
'Probability'=>'Probabilidade',
      
      
//Strings added for Quotes module fields
'Subject'=>'Assunto',
'Quote Stage'=>'Estágio Cotação',
'Valid Till'=>'Válido até',
'Team'=>'Equipe',
'Contact Name'=>'Nome Contato',
'Carrier'=>'Entregador',
'Shipping'=>'Entrega',
'Inventory Manager'=>'Almoxarife',
      
//Strings added for Sales Orders module fields
'Customer No'=>'Cód. Cliente',
'Quote Name'=>'Nome Cotação',
'Purchase Order'=>'Pedido Compra',
'Due Date'=>'Data Vencimento',
'Pending'=>'Pendente',
'Sales Commission'=>'Comissão Vendas',
'Excise Duty'=>'IPI',
      
//Strings added for Invoices module fields
'Sales Order'=>'Pedido Vendas',
'Invoice Date'=>'Data Fatura',
      
//Strings added for Product module fields
'Product Active'=>'Produto Ativo',
'Product Category'=>'Categoria Produto',
'Sales Start Date'=>'Data Início Vendas',
'Sales End Date'=>'Data Final Vendas',
'Support Start Date'=>'Data Início Suporte',
'Support Expiry Date'=>'Data Final Suporte',
'Vendor Name'=>'Nome Fornecedor',
'Mfr PartNo'=>'Cód Fabricante',
'Vendor PartNo'=>'Cód Fornecedor',
      
'Serial No'=>'No. Serial',
'Product Sheet'=>'Ficha Produto',
'GL Account'=>'Conta Plano Contas',
      
//Strings added for Price book module fields
'Price Book Name'=>'Nome Lista Preço',
'Active'=>'Ativo',
      
//Strings added for tasks & events module fields
'Start Date & Time'=>'Data & Hora Início',
      
//error message
'Missing required fields'=>'vtiger_fields requeridos ausentes',
//Strings added for campaigns
'Campaign Name'=>'Nome Campanha',
'Campaign Type'=>'Tipo Campanha',
'Product'=>'Produto',
'Campaign Status'=>'Status Campanha',
'Expected Revenue'=>'Receita Esperada',
'Budget Cost'=>'Custo Orçado',
'Actual Cost'=>'Custo Atual',
'Expected Response'=>'Resposta Esperada',
'Num Sent'=>'Número Envio',
'Target Audience'=>'Público Alvo',
'TargetSize'=>'Tamanho Alvo',
'Sponsor'=>'Patrocinador',
'Expected Sales Count'=>'Previsão Vendas',
'Expected Response Count'=>'Previsão Resposta',
'Expected ROI'=>'Previsão ROI',
'Actual Sales Count'=>'Vendas Atual',
'Actual Response Count'=>'Resposta Atual',
'Actual ROI'=>'ROI Atual',
      

      
//Added for customview.tpl
      
'LBL_Select_a_Column'=>'Selecione uma Coluna',
'Missing_required_fields'=>'Campos requeridos ausentes',
'Details'=>'Detalhes',
'New_Custom_View'=>'Nova Visualização Customizada',
'Edit_Custom_View'=>'Editar Visualização Customizada',
'LBL_AF_HDR5'=>'O Filtro Simples de Data permite-lhe selecionar dados baseados na
<b>Data Criação da Organização</b> ou <b>Data Modificação da Organização</b>',
'Select_Duration'=>'Selecione Duração',
'Simple_Time_Filter'=>'Filtro Simples de Data',
'Start_Date'=>'Data Inicial',
'End_Date'=>'Data Final',
'LBL_RULE'=>'REGRA',

// Added/Updated for vtiger CRM 5.0.4
'not equal to'=>'Diferente de',
'starts with'=>'Início com',
'ends with'=>'Final com',
//'Product Code'=>'Product Code',

// Added after 5.0.4 GA

//Added for Role based Custom filters 
'LBL_SET_AS_PUBLIC'=>'Definir como Público',
'LBL_NEW'=>'Novo',
'LBL_EDIT'=>'Editar',
'LBL_STATUS_PUBLIC_APPROVE'=>'Aprovar',
'LBL_STATUS_PUBLIC_DENY'=>'Negar',

'LBL_ADVANCED_FILTER' => 'Regra',
);
?>
